@@ -6,11 +6,14 @@ from .lib.util import objects, exceptions
 
 
 class Client(object):
-    def __init__(self, mongoUri: str, siteUrl: str):
+    def __init__(self, mongoUri: str, siteUrl: str, debug: bool):
         self.mongoDb = mongoUri
         self.siteUri = siteUrl
+        self.debugMode = debug
         mongoCli = MongoClient('MONGOURL')
         self.db = mongoCli["easyvanity"]
+        if debug == True:
+            print('Attempted connection to the database.')
 
     def createVanity(self, vanityLink: str, ownerId: str, callbackUrl: str):
         if self.mongoDb is None:
